Learn R Programming

SGSeq (version 1.6.2)

SGVariants: Splice graph variants

Description

Creates an instance of S4 class SGVariants for storing splice variants.

Usage

SGVariants(x)

Arguments

x
GRangesList of SGFeatures with appropriate outer metadata columns

Value

  • SGVariants object

Details

SGVariants includes columns as described below.

{from and to indicate the variant start and end, respectively. from nodes are splice donors (D) or transcript starts (S). to nodes are splice acceptors (A) or transcript ends (E).} {type and featureID describe the variant in terms of the splice graph features that make up the variant.} {segmentID specifies unique identifiers labelling unbranched segments of the splice graph.} {closed5p indicates whether nodes in the variant can be reached from nodes outside of the variant exclusively through the from node.} {closed3p indicates whether nodes in the variant can reach nodes outside of the variant exclusively through the to node.} {closed5pEvent indicates whether nodes in the event can be reached from nodes outside of the event exclusively through the from node.} {closed3pEvent indicates whether nodes in the event can reach nodes outside of the event exclusively through the to node.} {geneID has the same interpretation as for SGFeatures.} {eventID and variantID are unique identifiers for each event and variant, respectively.} {featureID5p and featureID3p indicate representative features used for variant quantification at the start and end of the variant, respectively.} featureID5pEvent and featureID3pEvent indicate the ensemble of representative features at the start and end of the event, respectively. {txName indicates structurally compatible transcripts.} {geneName behaves as for SGFeatures.} {variantType indicates whether a splice variant is consistent with a canonical splice event (for a list of possible values, see the manual page for annotateSGVariants).} {variantName provides a unique name for each splice variant (for details, see the manual page for makeVariantNames).}

Examples

Run this code
sgv <- SGVariants()

Run the code above in your browser using DataLab