FPKM(object)
FPKM(object) <- value
countsVariant5p(object)
countsVariant5p(object) <- value
countsVariant3p(object)
countsVariant3p(object) <- value
countsTotal5p(object)
countsTotal5p(object) <- value
countsTotal3p(object)
countsTotal3p(object) <- value
countsVariant(object)
countsVariant(object) <- value
countsTotal(object)
countsTotal(object) <- value
variantFreq(object)
variantFreq(object) <- value
"counts"(object)
"counts"(object) <- value
"FPKM"(object)
"FPKM"(object) <- value
"countsVariant5p"(object)
"countsVariant5p"(object) <- value
"countsVariant3p"(object)
"countsVariant3p"(object) <- value
"countsTotal5p"(object)
"countsTotal5p"(object) <- value
"countsTotal3p"(object)
"countsTotal3p"(object) <- value
"variantFreq"(object)
"variantFreq"(object) <- value
"countsVariant"(object)
"countsVariant"(object) <- value
"countsTotal"(object)
"countsTotal"(object) <- valueCounts objects defined in the SGSeq package contain
different types of assay data. For example, class SGFeatureCounts
contains assays counts and FPKM.To facilitate accessing and modifying assays, for each assay there exists a function with name identical to the assay name that can be used to access and modify it (see examples).
x <- counts(sgfc)
y <- FPKM(sgfc)
Run the code above in your browser using DataLab