convertToSGFeatures(x, coerce = FALSE)TxFeatures objectSGFeatures object
Entries for splice donor and acceptor sites (positions immediately upstream and downstream of introns, respectively) are added.
In the returned SGFeatures object, column slots splice5p
and splice3p indicate whether compatibility with an exon bin
requires a fragment to be spliced at the 5' or 3' boundary, respectively.
splice5p (splice3p) is TRUE if the first
(last) position of the exon coincides with a splice acceptor (donor),
and it is not adjacent to a neighboring exon bin.
Each feature is assigned a unique feature and gene identifier,
stored in column slots featureID and geneID,
respectively. The latter indicates features that belong to the
same gene, represented by a connected component in the splice graph.
sgf <- convertToSGFeatures(txf)
Run the code above in your browser using DataLab