Learn R Programming

SGSeq (version 1.4.0)

predictCandidatesTerminal: Identify candidate terminal exons

Description

Identify candidate terminal exons based on previously identified splice sites and regions with sufficient read coverage.

Usage

predictCandidatesTerminal(islands, splicesites, type = c("exon_L", "exon_R"))

Arguments

islands
IRanges of genomic regions with minimal read coverage required for internal exon prediction
splicesites
IRanges of splice sites with metadata columns “type” and “N”
type
Character string indicating whether terminal exons should be identified to the left (“exon_L”) or right (“exon_R”) of provided splice sites

Value

IRanges of candidate terminal exons