type(x) <- valuetxName(x)
txName(x) <- value
geneName(x)
geneName(x) <- value
featureID(x)
featureID(x) <- value
geneID(x)
geneID(x) <- value
splice5p(x)
splice5p(x) <- value
splice3p(x)
splice3p(x) <- value
from(x) <- value
to(x) <- value
segmentID(x)
segmentID(x) <- value
variantID(x)
variantID(x) <- value
eventID(x)
eventID(x) <- value
closed5p(x)
closed5p(x) <- value
closed3p(x)
closed3p(x) <- value
closed5pEvent(x)
closed5pEvent(x) <- value
closed3pEvent(x)
closed3pEvent(x) <- value
variantType(x)
variantType(x) <- value
variantName(x)
variantName(x) <- value
featureID5p(x)
featureID5p(x) <- value
featureID3p(x)
featureID3p(x) <- value
featureID5pEvent(x)
featureID5pEvent(x) <- value
featureID3pEvent(x)
featureID3pEvent(x) <- value
## S3 method for class 'Features':
type(x)
## S3 method for class 'Paths':
type(x)
## S3 method for class 'Counts':
type(x)
## S3 method for class 'Features':
type(x) <- value
## S3 method for class 'Paths':
type(x) <- value
## S3 method for class 'Counts':
type(x) <- value
## S3 method for class 'Features':
txName(x)
## S3 method for class 'Paths':
txName(x)
## S3 method for class 'Counts':
txName(x)
## S3 method for class 'Features':
txName(x) <- value
## S3 method for class 'Paths':
txName(x) <- value
## S3 method for class 'Counts':
txName(x) <- value
## S3 method for class 'Features':
geneName(x)
## S3 method for class 'Paths':
geneName(x)
## S3 method for class 'Counts':
geneName(x)
## S3 method for class 'Features':
geneName(x) <- value
## S3 method for class 'Paths':
geneName(x) <- value
## S3 method for class 'Counts':
geneName(x) <- value
## S3 method for class 'SGFeatures':
featureID(x)
## S3 method for class 'Paths':
featureID(x)
## S3 method for class 'Counts':
featureID(x)
## S3 method for class 'SGFeatures':
featureID(x) <- value
## S3 method for class 'Paths':
featureID(x) <- value
## S3 method for class 'Counts':
featureID(x) <- value
## S3 method for class 'SGFeatures':
geneID(x)
## S3 method for class 'Paths':
geneID(x)
## S3 method for class 'Counts':
geneID(x)
## S3 method for class 'SGFeatures':
geneID(x) <- value
## S3 method for class 'Paths':
geneID(x) <- value
## S3 method for class 'Counts':
geneID(x) <- value
## S3 method for class 'SGFeatures':
splice5p(x)
## S3 method for class 'SGSegments':
splice5p(x)
## S3 method for class 'SGFeatureCounts':
splice5p(x)
## S3 method for class 'SGFeatures':
splice5p(x) <- value
## S3 method for class 'SGSegments':
splice5p(x) <- value
## S3 method for class 'SGFeatureCounts':
splice5p(x) <- value
## S3 method for class 'SGFeatures':
splice3p(x)
## S3 method for class 'SGSegments':
splice3p(x)
## S3 method for class 'SGFeatureCounts':
splice3p(x)
## S3 method for class 'SGFeatures':
splice3p(x) <- value
## S3 method for class 'SGSegments':
splice3p(x) <- value
## S3 method for class 'SGFeatureCounts':
splice3p(x) <- value
## S3 method for class 'Paths':
segmentID(x)
## S3 method for class 'SGVariantCounts':
segmentID(x)
## S3 method for class 'Paths':
segmentID(x) <- value
## S3 method for class 'SGVariantCounts':
segmentID(x) <- value
## S3 method for class 'Paths':
from(x)
## S3 method for class 'SGVariantCounts':
from(x)
## S3 method for class 'Paths':
from(x) <- value
## S3 method for class 'SGVariantCounts':
from(x) <- value
## S3 method for class 'Paths':
to(x)
## S3 method for class 'SGVariantCounts':
to(x)
## S3 method for class 'Paths':
to(x) <- value
## S3 method for class 'SGVariantCounts':
to(x) <- value
## S3 method for class 'SGVariants':
eventID(x)
## S3 method for class 'SGVariantCounts':
eventID(x)
## S3 method for class 'SGVariants':
eventID(x) <- value
## S3 method for class 'SGVariantCounts':
eventID(x) <- value
## S3 method for class 'SGVariants':
variantID(x)
## S3 method for class 'SGVariantCounts':
variantID(x)
## S3 method for class 'SGVariants':
variantID(x) <- value
## S3 method for class 'SGVariantCounts':
variantID(x) <- value
## S3 method for class 'SGVariants':
closed5p(x)
## S3 method for class 'SGVariantCounts':
closed5p(x)
## S3 method for class 'SGVariants':
closed5p(x) <- value
## S3 method for class 'SGVariantCounts':
closed5p(x) <- value
## S3 method for class 'SGVariants':
closed3p(x)
## S3 method for class 'SGVariantCounts':
closed3p(x)
## S3 method for class 'SGVariants':
closed3p(x) <- value
## S3 method for class 'SGVariantCounts':
closed3p(x) <- value
## S3 method for class 'SGVariants':
closed5pEvent(x)
## S3 method for class 'SGVariantCounts':
closed5pEvent(x)
## S3 method for class 'SGVariants':
closed5pEvent(x) <- value
## S3 method for class 'SGVariantCounts':
closed5pEvent(x) <- value
## S3 method for class 'SGVariants':
closed3pEvent(x)
## S3 method for class 'SGVariantCounts':
closed3pEvent(x)
## S3 method for class 'SGVariants':
closed3pEvent(x) <- value
## S3 method for class 'SGVariantCounts':
closed3pEvent(x) <- value
## S3 method for class 'SGVariants':
variantName(x)
## S3 method for class 'SGVariantCounts':
variantName(x)
## S3 method for class 'SGVariants':
variantName(x) <- value
## S3 method for class 'SGVariantCounts':
variantName(x) <- value
## S3 method for class 'SGVariants':
variantType(x)
## S3 method for class 'SGVariantCounts':
variantType(x)
## S3 method for class 'SGVariants':
variantType(x) <- value
## S3 method for class 'SGVariantCounts':
variantType(x) <- value
## S3 method for class 'SGVariants':
featureID5p(x)
## S3 method for class 'SGVariantCounts':
featureID5p(x)
## S3 method for class 'SGVariants':
featureID5p(x) <- value
## S3 method for class 'SGVariantCounts':
featureID5p(x) <- value
## S3 method for class 'SGVariants':
featureID3p(x)
## S3 method for class 'SGVariantCounts':
featureID3p(x)
## S3 method for class 'SGVariants':
featureID3p(x) <- value
## S3 method for class 'SGVariantCounts':
featureID3p(x) <- value
## S3 method for class 'SGVariants':
featureID5pEvent(x)
## S3 method for class 'SGVariantCounts':
featureID5pEvent(x)
## S3 method for class 'SGVariants':
featureID5pEvent(x) <- value
## S3 method for class 'SGVariantCounts':
featureID5pEvent(x) <- value
## S3 method for class 'SGVariants':
featureID3pEvent(x)
## S3 method for class 'SGVariantCounts':
featureID3pEvent(x)
## S3 method for class 'SGVariants':
featureID3pEvent(x) <- value
## S3 method for class 'SGVariantCounts':
featureID3pEvent(x) <- value
SGSeq package contain metadata columns
that store information for each element in the object. For example, class
TxFeatures contains a column type that indicates feature
type. The specific columns contained in an object depend on its class.head(type(txf_ann))
head(type(sgf_ann))Run the code above in your browser using DataLab